# Datamaestro API

```{toctree}
---
maxdepth: 1
caption: "Contents:"
---
download
data
records
```

The API is composed of:

- [Specify what to download](download/)
- [Describing data](data/)
- [Records](records/)
